==> paraview_5.4.1+dfsg4.orig.tar.xz: paraview-5.4.1+dfsg4/Qt/ApplicationComponents/pqCrashRecoveryBehavior.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqCrashRecoveryBehavior.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqCrashRecoveryBehavior_h
#define pqCrashRecoveryBehavior_h

#include "pqApplicationComponentsModule.h"
#include <QObject>
#include <QTimer>

class pqServer;

/**
* @ingroup Behaviors
* pqCrashRecoveryBehavior manages saving/loading of crash recovery state. If
* you want your application to be able to recover from crashes, simply
* instantiate this behavior and ensure that state saving/loading works
* correctly.
*/
class PQAPPLICATIONCOMPONENTS_EXPORT pqCrashRecoveryBehavior : public QObject
{
  Q_OBJECT
  typedef QObject Superclass;

public:
  pqCrashRecoveryBehavior(QObject* parent = 0);
  ~pqCrashRecoveryBehavior();

protected slots:
  void delayedSaveRecoveryState();
  void saveRecoveryState();
  void onServerAdded(pqServer* server);
  void onServerDisconnect();

private:
  Q_DISABLE_COPY(pqCrashRecoveryBehavior)

  QTimer Timer;
};

#endif

==> paraview_5.7.0.orig.tar.xz: paraview-5.7.0/Qt/ApplicationComponents/pqCrashRecoveryBehavior.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqCrashRecoveryBehavior.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqCrashRecoveryBehavior_h
#define pqCrashRecoveryBehavior_h

#include "pqApplicationComponentsModule.h"
#include <QObject>
#include <QTimer>

class pqServer;

/**
* @ingroup Behaviors
* pqCrashRecoveryBehavior manages saving/loading of crash recovery state. If
* you want your application to be able to recover from crashes, simply
* instantiate this behavior and ensure that state saving/loading works
* correctly.
*/
class PQAPPLICATIONCOMPONENTS_EXPORT pqCrashRecoveryBehavior : public QObject
{
  Q_OBJECT
  typedef QObject Superclass;

public:
  pqCrashRecoveryBehavior(QObject* parent = 0);
  ~pqCrashRecoveryBehavior() override;

protected slots:
  void delayedSaveRecoveryState();
  void saveRecoveryState();
  void onServerAdded(pqServer* server);
  void onServerDisconnect();

private:
  Q_DISABLE_COPY(pqCrashRecoveryBehavior)

  QTimer Timer;
};

#endif
